# Authors

This file lists the contributors to the BRAID-DSPy project.

## Maintainers

- **Ziya Civan** - [@ziyacivan](https://github.com/ziyacivan) - Initial work and project maintainer

## Contributors

<!-- Add contributors here as they contribute to the project -->
<!-- Format: - **Name** - [@username](https://github.com/username) - Description of contribution -->

## Acknowledgments

- **Armağan Amcalar** ([@dashersw](https://github.com/dashersw)) - For introducing the BRAID architecture
- **OpenServ** - For the BRAID architecture and research
- **DSPy Team** - For the DSPy framework

---

If you've contributed to this project and your name is missing, please open a pull request to add it!

